/*******************************************************************************
* File Name: DACOut.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_DACOut_H) /* Pins DACOut_H */
#define CY_PINS_DACOut_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "DACOut_aliases.h"


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    DACOut_Write(uint8 value) ;
void    DACOut_SetDriveMode(uint8 mode) ;
uint8   DACOut_ReadDataReg(void) ;
uint8   DACOut_Read(void) ;
void    DACOut_SetInterruptMode(uint16 position, uint16 mode) ;
uint8   DACOut_ClearInterrupt(void) ;
/** @} general */

/***************************************
*           API Constants        
***************************************/

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the DACOut_SetDriveMode() function.
     *  @{
     */
        /* Drive Modes */
        #define DACOut_DM_ALG_HIZ         PIN_DM_ALG_HIZ   /**< \brief High Impedance Analog   */
        #define DACOut_DM_DIG_HIZ         PIN_DM_DIG_HIZ   /**< \brief High Impedance Digital  */
        #define DACOut_DM_RES_UP          PIN_DM_RES_UP    /**< \brief Resistive Pull Up       */
        #define DACOut_DM_RES_DWN         PIN_DM_RES_DWN   /**< \brief Resistive Pull Down     */
        #define DACOut_DM_OD_LO           PIN_DM_OD_LO     /**< \brief Open Drain, Drives Low  */
        #define DACOut_DM_OD_HI           PIN_DM_OD_HI     /**< \brief Open Drain, Drives High */
        #define DACOut_DM_STRONG          PIN_DM_STRONG    /**< \brief Strong Drive            */
        #define DACOut_DM_RES_UPDWN       PIN_DM_RES_UPDWN /**< \brief Resistive Pull Up/Down  */
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define DACOut_MASK               DACOut__MASK
#define DACOut_SHIFT              DACOut__SHIFT
#define DACOut_WIDTH              1u

/* Interrupt constants */
#if defined(DACOut__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in DACOut_SetInterruptMode() function.
     *  @{
     */
        #define DACOut_INTR_NONE      (uint16)(0x0000u)   /**< \brief Disabled             */
        #define DACOut_INTR_RISING    (uint16)(0x0001u)   /**< \brief Rising edge trigger  */
        #define DACOut_INTR_FALLING   (uint16)(0x0002u)   /**< \brief Falling edge trigger */
        #define DACOut_INTR_BOTH      (uint16)(0x0003u)   /**< \brief Both edge trigger    */
        /** @} intrMode */
/** @} group_constants */

    #define DACOut_INTR_MASK      (0x01u)
#endif /* (DACOut__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define DACOut_PS                     (* (reg8 *) DACOut__PS)
/* Data Register */
#define DACOut_DR                     (* (reg8 *) DACOut__DR)
/* Port Number */
#define DACOut_PRT_NUM                (* (reg8 *) DACOut__PRT) 
/* Connect to Analog Globals */                                                  
#define DACOut_AG                     (* (reg8 *) DACOut__AG)                       
/* Analog MUX bux enable */
#define DACOut_AMUX                   (* (reg8 *) DACOut__AMUX) 
/* Bidirectional Enable */                                                        
#define DACOut_BIE                    (* (reg8 *) DACOut__BIE)
/* Bit-mask for Aliased Register Access */
#define DACOut_BIT_MASK               (* (reg8 *) DACOut__BIT_MASK)
/* Bypass Enable */
#define DACOut_BYP                    (* (reg8 *) DACOut__BYP)
/* Port wide control signals */                                                   
#define DACOut_CTL                    (* (reg8 *) DACOut__CTL)
/* Drive Modes */
#define DACOut_DM0                    (* (reg8 *) DACOut__DM0) 
#define DACOut_DM1                    (* (reg8 *) DACOut__DM1)
#define DACOut_DM2                    (* (reg8 *) DACOut__DM2) 
/* Input Buffer Disable Override */
#define DACOut_INP_DIS                (* (reg8 *) DACOut__INP_DIS)
/* LCD Common or Segment Drive */
#define DACOut_LCD_COM_SEG            (* (reg8 *) DACOut__LCD_COM_SEG)
/* Enable Segment LCD */
#define DACOut_LCD_EN                 (* (reg8 *) DACOut__LCD_EN)
/* Slew Rate Control */
#define DACOut_SLW                    (* (reg8 *) DACOut__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define DACOut_PRTDSI__CAPS_SEL       (* (reg8 *) DACOut__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define DACOut_PRTDSI__DBL_SYNC_IN    (* (reg8 *) DACOut__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define DACOut_PRTDSI__OE_SEL0        (* (reg8 *) DACOut__PRTDSI__OE_SEL0) 
#define DACOut_PRTDSI__OE_SEL1        (* (reg8 *) DACOut__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define DACOut_PRTDSI__OUT_SEL0       (* (reg8 *) DACOut__PRTDSI__OUT_SEL0) 
#define DACOut_PRTDSI__OUT_SEL1       (* (reg8 *) DACOut__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define DACOut_PRTDSI__SYNC_OUT       (* (reg8 *) DACOut__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(DACOut__SIO_CFG)
    #define DACOut_SIO_HYST_EN        (* (reg8 *) DACOut__SIO_HYST_EN)
    #define DACOut_SIO_REG_HIFREQ     (* (reg8 *) DACOut__SIO_REG_HIFREQ)
    #define DACOut_SIO_CFG            (* (reg8 *) DACOut__SIO_CFG)
    #define DACOut_SIO_DIFF           (* (reg8 *) DACOut__SIO_DIFF)
#endif /* (DACOut__SIO_CFG) */

/* Interrupt Registers */
#if defined(DACOut__INTSTAT)
    #define DACOut_INTSTAT             (* (reg8 *) DACOut__INTSTAT)
    #define DACOut_SNAP                (* (reg8 *) DACOut__SNAP)
    
	#define DACOut_0_INTTYPE_REG 		(* (reg8 *) DACOut__0__INTTYPE)
#endif /* (DACOut__INTSTAT) */

#endif /* End Pins DACOut_H */


/* [] END OF FILE */
