/*******************************************************************************
* File Name: InputClock.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_InputClock_H) /* Pins InputClock_H */
#define CY_PINS_InputClock_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "InputClock_aliases.h"


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    InputClock_Write(uint8 value) ;
void    InputClock_SetDriveMode(uint8 mode) ;
uint8   InputClock_ReadDataReg(void) ;
uint8   InputClock_Read(void) ;
void    InputClock_SetInterruptMode(uint16 position, uint16 mode) ;
uint8   InputClock_ClearInterrupt(void) ;
/** @} general */

/***************************************
*           API Constants        
***************************************/

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the InputClock_SetDriveMode() function.
     *  @{
     */
        /* Drive Modes */
        #define InputClock_DM_ALG_HIZ         PIN_DM_ALG_HIZ   /**< \brief High Impedance Analog   */
        #define InputClock_DM_DIG_HIZ         PIN_DM_DIG_HIZ   /**< \brief High Impedance Digital  */
        #define InputClock_DM_RES_UP          PIN_DM_RES_UP    /**< \brief Resistive Pull Up       */
        #define InputClock_DM_RES_DWN         PIN_DM_RES_DWN   /**< \brief Resistive Pull Down     */
        #define InputClock_DM_OD_LO           PIN_DM_OD_LO     /**< \brief Open Drain, Drives Low  */
        #define InputClock_DM_OD_HI           PIN_DM_OD_HI     /**< \brief Open Drain, Drives High */
        #define InputClock_DM_STRONG          PIN_DM_STRONG    /**< \brief Strong Drive            */
        #define InputClock_DM_RES_UPDWN       PIN_DM_RES_UPDWN /**< \brief Resistive Pull Up/Down  */
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define InputClock_MASK               InputClock__MASK
#define InputClock_SHIFT              InputClock__SHIFT
#define InputClock_WIDTH              1u

/* Interrupt constants */
#if defined(InputClock__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in InputClock_SetInterruptMode() function.
     *  @{
     */
        #define InputClock_INTR_NONE      (uint16)(0x0000u)   /**< \brief Disabled             */
        #define InputClock_INTR_RISING    (uint16)(0x0001u)   /**< \brief Rising edge trigger  */
        #define InputClock_INTR_FALLING   (uint16)(0x0002u)   /**< \brief Falling edge trigger */
        #define InputClock_INTR_BOTH      (uint16)(0x0003u)   /**< \brief Both edge trigger    */
        /** @} intrMode */
/** @} group_constants */

    #define InputClock_INTR_MASK      (0x01u)
#endif /* (InputClock__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define InputClock_PS                     (* (reg8 *) InputClock__PS)
/* Data Register */
#define InputClock_DR                     (* (reg8 *) InputClock__DR)
/* Port Number */
#define InputClock_PRT_NUM                (* (reg8 *) InputClock__PRT) 
/* Connect to Analog Globals */                                                  
#define InputClock_AG                     (* (reg8 *) InputClock__AG)                       
/* Analog MUX bux enable */
#define InputClock_AMUX                   (* (reg8 *) InputClock__AMUX) 
/* Bidirectional Enable */                                                        
#define InputClock_BIE                    (* (reg8 *) InputClock__BIE)
/* Bit-mask for Aliased Register Access */
#define InputClock_BIT_MASK               (* (reg8 *) InputClock__BIT_MASK)
/* Bypass Enable */
#define InputClock_BYP                    (* (reg8 *) InputClock__BYP)
/* Port wide control signals */                                                   
#define InputClock_CTL                    (* (reg8 *) InputClock__CTL)
/* Drive Modes */
#define InputClock_DM0                    (* (reg8 *) InputClock__DM0) 
#define InputClock_DM1                    (* (reg8 *) InputClock__DM1)
#define InputClock_DM2                    (* (reg8 *) InputClock__DM2) 
/* Input Buffer Disable Override */
#define InputClock_INP_DIS                (* (reg8 *) InputClock__INP_DIS)
/* LCD Common or Segment Drive */
#define InputClock_LCD_COM_SEG            (* (reg8 *) InputClock__LCD_COM_SEG)
/* Enable Segment LCD */
#define InputClock_LCD_EN                 (* (reg8 *) InputClock__LCD_EN)
/* Slew Rate Control */
#define InputClock_SLW                    (* (reg8 *) InputClock__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define InputClock_PRTDSI__CAPS_SEL       (* (reg8 *) InputClock__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define InputClock_PRTDSI__DBL_SYNC_IN    (* (reg8 *) InputClock__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define InputClock_PRTDSI__OE_SEL0        (* (reg8 *) InputClock__PRTDSI__OE_SEL0) 
#define InputClock_PRTDSI__OE_SEL1        (* (reg8 *) InputClock__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define InputClock_PRTDSI__OUT_SEL0       (* (reg8 *) InputClock__PRTDSI__OUT_SEL0) 
#define InputClock_PRTDSI__OUT_SEL1       (* (reg8 *) InputClock__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define InputClock_PRTDSI__SYNC_OUT       (* (reg8 *) InputClock__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(InputClock__SIO_CFG)
    #define InputClock_SIO_HYST_EN        (* (reg8 *) InputClock__SIO_HYST_EN)
    #define InputClock_SIO_REG_HIFREQ     (* (reg8 *) InputClock__SIO_REG_HIFREQ)
    #define InputClock_SIO_CFG            (* (reg8 *) InputClock__SIO_CFG)
    #define InputClock_SIO_DIFF           (* (reg8 *) InputClock__SIO_DIFF)
#endif /* (InputClock__SIO_CFG) */

/* Interrupt Registers */
#if defined(InputClock__INTSTAT)
    #define InputClock_INTSTAT             (* (reg8 *) InputClock__INTSTAT)
    #define InputClock_SNAP                (* (reg8 *) InputClock__SNAP)
    
	#define InputClock_0_INTTYPE_REG 		(* (reg8 *) InputClock__0__INTTYPE)
#endif /* (InputClock__INTSTAT) */

#endif /* End Pins InputClock_H */


/* [] END OF FILE */
