/*******************************************************************************
* File Name: LED4.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_LED4_H) /* Pins LED4_H */
#define CY_PINS_LED4_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "LED4_aliases.h"


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    LED4_Write(uint8 value) ;
void    LED4_SetDriveMode(uint8 mode) ;
uint8   LED4_ReadDataReg(void) ;
uint8   LED4_Read(void) ;
void    LED4_SetInterruptMode(uint16 position, uint16 mode) ;
uint8   LED4_ClearInterrupt(void) ;
/** @} general */

/***************************************
*           API Constants        
***************************************/

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the LED4_SetDriveMode() function.
     *  @{
     */
        /* Drive Modes */
        #define LED4_DM_ALG_HIZ         PIN_DM_ALG_HIZ   /**< \brief High Impedance Analog   */
        #define LED4_DM_DIG_HIZ         PIN_DM_DIG_HIZ   /**< \brief High Impedance Digital  */
        #define LED4_DM_RES_UP          PIN_DM_RES_UP    /**< \brief Resistive Pull Up       */
        #define LED4_DM_RES_DWN         PIN_DM_RES_DWN   /**< \brief Resistive Pull Down     */
        #define LED4_DM_OD_LO           PIN_DM_OD_LO     /**< \brief Open Drain, Drives Low  */
        #define LED4_DM_OD_HI           PIN_DM_OD_HI     /**< \brief Open Drain, Drives High */
        #define LED4_DM_STRONG          PIN_DM_STRONG    /**< \brief Strong Drive            */
        #define LED4_DM_RES_UPDWN       PIN_DM_RES_UPDWN /**< \brief Resistive Pull Up/Down  */
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define LED4_MASK               LED4__MASK
#define LED4_SHIFT              LED4__SHIFT
#define LED4_WIDTH              1u

/* Interrupt constants */
#if defined(LED4__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in LED4_SetInterruptMode() function.
     *  @{
     */
        #define LED4_INTR_NONE      (uint16)(0x0000u)   /**< \brief Disabled             */
        #define LED4_INTR_RISING    (uint16)(0x0001u)   /**< \brief Rising edge trigger  */
        #define LED4_INTR_FALLING   (uint16)(0x0002u)   /**< \brief Falling edge trigger */
        #define LED4_INTR_BOTH      (uint16)(0x0003u)   /**< \brief Both edge trigger    */
        /** @} intrMode */
/** @} group_constants */

    #define LED4_INTR_MASK      (0x01u)
#endif /* (LED4__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define LED4_PS                     (* (reg8 *) LED4__PS)
/* Data Register */
#define LED4_DR                     (* (reg8 *) LED4__DR)
/* Port Number */
#define LED4_PRT_NUM                (* (reg8 *) LED4__PRT) 
/* Connect to Analog Globals */                                                  
#define LED4_AG                     (* (reg8 *) LED4__AG)                       
/* Analog MUX bux enable */
#define LED4_AMUX                   (* (reg8 *) LED4__AMUX) 
/* Bidirectional Enable */                                                        
#define LED4_BIE                    (* (reg8 *) LED4__BIE)
/* Bit-mask for Aliased Register Access */
#define LED4_BIT_MASK               (* (reg8 *) LED4__BIT_MASK)
/* Bypass Enable */
#define LED4_BYP                    (* (reg8 *) LED4__BYP)
/* Port wide control signals */                                                   
#define LED4_CTL                    (* (reg8 *) LED4__CTL)
/* Drive Modes */
#define LED4_DM0                    (* (reg8 *) LED4__DM0) 
#define LED4_DM1                    (* (reg8 *) LED4__DM1)
#define LED4_DM2                    (* (reg8 *) LED4__DM2) 
/* Input Buffer Disable Override */
#define LED4_INP_DIS                (* (reg8 *) LED4__INP_DIS)
/* LCD Common or Segment Drive */
#define LED4_LCD_COM_SEG            (* (reg8 *) LED4__LCD_COM_SEG)
/* Enable Segment LCD */
#define LED4_LCD_EN                 (* (reg8 *) LED4__LCD_EN)
/* Slew Rate Control */
#define LED4_SLW                    (* (reg8 *) LED4__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define LED4_PRTDSI__CAPS_SEL       (* (reg8 *) LED4__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define LED4_PRTDSI__DBL_SYNC_IN    (* (reg8 *) LED4__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define LED4_PRTDSI__OE_SEL0        (* (reg8 *) LED4__PRTDSI__OE_SEL0) 
#define LED4_PRTDSI__OE_SEL1        (* (reg8 *) LED4__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define LED4_PRTDSI__OUT_SEL0       (* (reg8 *) LED4__PRTDSI__OUT_SEL0) 
#define LED4_PRTDSI__OUT_SEL1       (* (reg8 *) LED4__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define LED4_PRTDSI__SYNC_OUT       (* (reg8 *) LED4__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(LED4__SIO_CFG)
    #define LED4_SIO_HYST_EN        (* (reg8 *) LED4__SIO_HYST_EN)
    #define LED4_SIO_REG_HIFREQ     (* (reg8 *) LED4__SIO_REG_HIFREQ)
    #define LED4_SIO_CFG            (* (reg8 *) LED4__SIO_CFG)
    #define LED4_SIO_DIFF           (* (reg8 *) LED4__SIO_DIFF)
#endif /* (LED4__SIO_CFG) */

/* Interrupt Registers */
#if defined(LED4__INTSTAT)
    #define LED4_INTSTAT             (* (reg8 *) LED4__INTSTAT)
    #define LED4_SNAP                (* (reg8 *) LED4__SNAP)
    
	#define LED4_0_INTTYPE_REG 		(* (reg8 *) LED4__0__INTTYPE)
#endif /* (LED4__INTSTAT) */

#endif /* End Pins LED4_H */


/* [] END OF FILE */
