/*******************************************************************************
* File Name: RefCounterClock.h
* Version 1.70
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_RefCounterClock_H)
#define CY_CLOCK_RefCounterClock_H

#include <cytypes.h>
#include <cyfitter.h>

/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v1_70 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

/***************************************
*        Function Prototypes
***************************************/

void RefCounterClock_Start(void) ;
void RefCounterClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void RefCounterClock_StopBlock(void) ;
#endif

void RefCounterClock_StandbyPower(uint8 state) ;
void RefCounterClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 RefCounterClock_GetDividerRegister(void) ;
void RefCounterClock_SetModeRegister(uint8 modeBitMask) ;
void RefCounterClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 RefCounterClock_GetModeRegister(void) ;
void RefCounterClock_SetSourceRegister(uint8 clkSource) ;
uint8 RefCounterClock_GetSourceRegister(void) ;
#if defined(RefCounterClock__CFG3)
void RefCounterClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 RefCounterClock_GetPhaseRegister(void) ;
#endif

#define RefCounterClock_Enable()                       RefCounterClock_Start()
#define RefCounterClock_Disable()                      RefCounterClock_Stop()
#define RefCounterClock_SetDivider(clkDivider)         RefCounterClock_SetDividerRegister(clkDivider, 1)
#define RefCounterClock_SetDividerValue(clkDivider)    RefCounterClock_SetDividerRegister((clkDivider) - 1, 1)
#define RefCounterClock_SetMode(clkMode)               RefCounterClock_SetModeRegister(clkMode)
#define RefCounterClock_SetSource(clkSource)           RefCounterClock_SetSourceRegister(clkSource)
#if defined(RefCounterClock__CFG3)
#define RefCounterClock_SetPhase(clkPhase)             RefCounterClock_SetPhaseRegister(clkPhase)
#define RefCounterClock_SetPhaseValue(clkPhase)        RefCounterClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define RefCounterClock_CLKEN              (* (reg8 *) RefCounterClock__PM_ACT_CFG)
#define RefCounterClock_CLKEN_PTR          ((reg8 *) RefCounterClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define RefCounterClock_CLKSTBY            (* (reg8 *) RefCounterClock__PM_STBY_CFG)
#define RefCounterClock_CLKSTBY_PTR        ((reg8 *) RefCounterClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define RefCounterClock_DIV_LSB            (* (reg8 *) RefCounterClock__CFG0)
#define RefCounterClock_DIV_LSB_PTR        ((reg8 *) RefCounterClock__CFG0)
#define RefCounterClock_DIV_PTR            ((reg16 *) RefCounterClock__CFG0)

/* Clock MSB divider configuration register. */
#define RefCounterClock_DIV_MSB            (* (reg8 *) RefCounterClock__CFG1)
#define RefCounterClock_DIV_MSB_PTR        ((reg8 *) RefCounterClock__CFG1)

/* Mode and source configuration register */
#define RefCounterClock_MOD_SRC            (* (reg8 *) RefCounterClock__CFG2)
#define RefCounterClock_MOD_SRC_PTR        ((reg8 *) RefCounterClock__CFG2)

#if defined(RefCounterClock__CFG3)
/* Analog clock phase configuration register */
#define RefCounterClock_PHASE              (* (reg8 *) RefCounterClock__CFG3)
#define RefCounterClock_PHASE_PTR          ((reg8 *) RefCounterClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define RefCounterClock_CLKEN_MASK         RefCounterClock__PM_ACT_MSK
#define RefCounterClock_CLKSTBY_MASK       RefCounterClock__PM_STBY_MSK

/* CFG2 field masks */
#define RefCounterClock_SRC_SEL_MSK        RefCounterClock__CFG2_SRC_SEL_MASK
#define RefCounterClock_MODE_MASK          (~(RefCounterClock_SRC_SEL_MSK))

#if defined(RefCounterClock__CFG3)
/* CFG3 phase mask */
#define RefCounterClock_PHASE_MASK         RefCounterClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_RefCounterClock_H */


/* [] END OF FILE */
