/*******************************************************************************
* File Name: CompClock.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_CompClock_H)
#define CY_CLOCK_CompClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void CompClock_Start(void) ;
void CompClock_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void CompClock_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void CompClock_StandbyPower(uint8 state) ;
void CompClock_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 CompClock_GetDividerRegister(void) ;
void CompClock_SetModeRegister(uint8 modeBitMask) ;
void CompClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 CompClock_GetModeRegister(void) ;
void CompClock_SetSourceRegister(uint8 clkSource) ;
uint8 CompClock_GetSourceRegister(void) ;
#if defined(CompClock__CFG3)
void CompClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 CompClock_GetPhaseRegister(void) ;
#endif /* defined(CompClock__CFG3) */

#define CompClock_Enable()                       CompClock_Start()
#define CompClock_Disable()                      CompClock_Stop()
#define CompClock_SetDivider(clkDivider)         CompClock_SetDividerRegister(clkDivider, 1u)
#define CompClock_SetDividerValue(clkDivider)    CompClock_SetDividerRegister((clkDivider) - 1u, 1u)
#define CompClock_SetMode(clkMode)               CompClock_SetModeRegister(clkMode)
#define CompClock_SetSource(clkSource)           CompClock_SetSourceRegister(clkSource)
#if defined(CompClock__CFG3)
#define CompClock_SetPhase(clkPhase)             CompClock_SetPhaseRegister(clkPhase)
#define CompClock_SetPhaseValue(clkPhase)        CompClock_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(CompClock__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define CompClock_CLKEN              (* (reg8 *) CompClock__PM_ACT_CFG)
#define CompClock_CLKEN_PTR          ((reg8 *) CompClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define CompClock_CLKSTBY            (* (reg8 *) CompClock__PM_STBY_CFG)
#define CompClock_CLKSTBY_PTR        ((reg8 *) CompClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define CompClock_DIV_LSB            (* (reg8 *) CompClock__CFG0)
#define CompClock_DIV_LSB_PTR        ((reg8 *) CompClock__CFG0)
#define CompClock_DIV_PTR            ((reg16 *) CompClock__CFG0)

/* Clock MSB divider configuration register. */
#define CompClock_DIV_MSB            (* (reg8 *) CompClock__CFG1)
#define CompClock_DIV_MSB_PTR        ((reg8 *) CompClock__CFG1)

/* Mode and source configuration register */
#define CompClock_MOD_SRC            (* (reg8 *) CompClock__CFG2)
#define CompClock_MOD_SRC_PTR        ((reg8 *) CompClock__CFG2)

#if defined(CompClock__CFG3)
/* Analog clock phase configuration register */
#define CompClock_PHASE              (* (reg8 *) CompClock__CFG3)
#define CompClock_PHASE_PTR          ((reg8 *) CompClock__CFG3)
#endif /* defined(CompClock__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define CompClock_CLKEN_MASK         CompClock__PM_ACT_MSK
#define CompClock_CLKSTBY_MASK       CompClock__PM_STBY_MSK

/* CFG2 field masks */
#define CompClock_SRC_SEL_MSK        CompClock__CFG2_SRC_SEL_MASK
#define CompClock_MODE_MASK          (~(CompClock_SRC_SEL_MSK))

#if defined(CompClock__CFG3)
/* CFG3 phase mask */
#define CompClock_PHASE_MASK         CompClock__CFG3_PHASE_DLY_MASK
#endif /* defined(CompClock__CFG3) */

#endif /* CY_CLOCK_CompClock_H */


/* [] END OF FILE */
