/*******************************************************************************
* File Name: InputCounter.h  
* Version 3.0
*
*  Description:
*   Contains the function prototypes and constants available to the counter
*   user module.
*
*   Note:
*    None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/
    
#if !defined(CY_COUNTER_InputCounter_H)
#define CY_COUNTER_InputCounter_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 InputCounter_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Counter_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Error message for removed InputCounter_CounterUDB_sCTRLReg_ctrlreg through optimization */
#ifdef InputCounter_CounterUDB_sCTRLReg_ctrlreg__REMOVED
    #error Counter_v3_0 detected with a constant 0 for the enable, a \
                                constant 0 for the count or constant 1 for \
                                the reset. This will prevent the component from\
                                operating.
#endif /* InputCounter_CounterUDB_sCTRLReg_ctrlreg__REMOVED */


/**************************************
*           Parameter Defaults        
**************************************/

#define InputCounter_Resolution            24u
#define InputCounter_UsingFixedFunction    0u
#define InputCounter_ControlRegRemoved     1u
#define InputCounter_COMPARE_MODE_SOFTWARE 0u
#define InputCounter_CAPTURE_MODE_SOFTWARE 0u
#define InputCounter_RunModeUsed           0u


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Mode API Support
 * Backup structure for Sleep Wake up operations
 *************************************************************************/
typedef struct
{
    uint8 CounterEnableState; 
    uint32 CounterUdb;         /* Current Counter Value */

    #if (!InputCounter_ControlRegRemoved)
        uint8 CounterControlRegister;               /* Counter Control Register */
    #endif /* (!InputCounter_ControlRegRemoved) */

}InputCounter_backupStruct;


/**************************************
 *  Function Prototypes
 *************************************/
void    InputCounter_Start(void) ;
void    InputCounter_Stop(void) ;
void    InputCounter_SetInterruptMode(uint8 interruptsMask) ;
uint8   InputCounter_ReadStatusRegister(void) ;
#define InputCounter_GetInterruptSource() InputCounter_ReadStatusRegister()
#if(!InputCounter_ControlRegRemoved)
    uint8   InputCounter_ReadControlRegister(void) ;
    void    InputCounter_WriteControlRegister(uint8 control) \
        ;
#endif /* (!InputCounter_ControlRegRemoved) */
#if (!(InputCounter_UsingFixedFunction && (CY_PSOC5A)))
    void    InputCounter_WriteCounter(uint32 counter) \
            ; 
#endif /* (!(InputCounter_UsingFixedFunction && (CY_PSOC5A))) */
uint32  InputCounter_ReadCounter(void) ;
uint32  InputCounter_ReadCapture(void) ;
void    InputCounter_WritePeriod(uint32 period) \
    ;
uint32  InputCounter_ReadPeriod( void ) ;
#if (!InputCounter_UsingFixedFunction)
    void    InputCounter_WriteCompare(uint32 compare) \
        ;
    uint32  InputCounter_ReadCompare( void ) \
        ;
#endif /* (!InputCounter_UsingFixedFunction) */

#if (InputCounter_COMPARE_MODE_SOFTWARE)
    void    InputCounter_SetCompareMode(uint8 compareMode) ;
#endif /* (InputCounter_COMPARE_MODE_SOFTWARE) */
#if (InputCounter_CAPTURE_MODE_SOFTWARE)
    void    InputCounter_SetCaptureMode(uint8 captureMode) ;
#endif /* (InputCounter_CAPTURE_MODE_SOFTWARE) */
void InputCounter_ClearFIFO(void)     ;
void InputCounter_Init(void)          ;
void InputCounter_Enable(void)        ;
void InputCounter_SaveConfig(void)    ;
void InputCounter_RestoreConfig(void) ;
void InputCounter_Sleep(void)         ;
void InputCounter_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Counter__CompareModes, Used in Compare Mode retained for backward compatibility of tests*/
#define InputCounter__B_COUNTER__LESS_THAN 1
#define InputCounter__B_COUNTER__LESS_THAN_OR_EQUAL 2
#define InputCounter__B_COUNTER__EQUAL 0
#define InputCounter__B_COUNTER__GREATER_THAN 3
#define InputCounter__B_COUNTER__GREATER_THAN_OR_EQUAL 4
#define InputCounter__B_COUNTER__SOFTWARE 5

/* Enumerated Type Counter_CompareModes */
#define InputCounter_CMP_MODE_LT 1u
#define InputCounter_CMP_MODE_LTE 2u
#define InputCounter_CMP_MODE_EQ 0u
#define InputCounter_CMP_MODE_GT 3u
#define InputCounter_CMP_MODE_GTE 4u
#define InputCounter_CMP_MODE_SOFTWARE_CONTROLLED 5u

/* Enumerated Type B_Counter__CaptureModes, Used in Capture Mode retained for backward compatibility of tests*/
#define InputCounter__B_COUNTER__NONE 0
#define InputCounter__B_COUNTER__RISING_EDGE 1
#define InputCounter__B_COUNTER__FALLING_EDGE 2
#define InputCounter__B_COUNTER__EITHER_EDGE 3
#define InputCounter__B_COUNTER__SOFTWARE_CONTROL 4

/* Enumerated Type Counter_CompareModes */
#define InputCounter_CAP_MODE_NONE 0u
#define InputCounter_CAP_MODE_RISE 1u
#define InputCounter_CAP_MODE_FALL 2u
#define InputCounter_CAP_MODE_BOTH 3u
#define InputCounter_CAP_MODE_SOFTWARE_CONTROLLED 4u


/***************************************
 *  Initialization Values
 **************************************/
#define InputCounter_CAPTURE_MODE_CONF       0u
#define InputCounter_INIT_PERIOD_VALUE       16777214u
#define InputCounter_INIT_COUNTER_VALUE      0u
#if (InputCounter_UsingFixedFunction)
#define InputCounter_INIT_INTERRUPTS_MASK    ((uint8)((uint8)0u << InputCounter_STATUS_ZERO_INT_EN_MASK_SHIFT))
#else
#define InputCounter_INIT_COMPARE_VALUE      16777214u
#define InputCounter_INIT_INTERRUPTS_MASK ((uint8)((uint8)0u << InputCounter_STATUS_ZERO_INT_EN_MASK_SHIFT) | \
        ((uint8)((uint8)0u << InputCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << InputCounter_STATUS_CMP_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << InputCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << InputCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT)))
#define InputCounter_DEFAULT_COMPARE_MODE    0u

#if( 0 != InputCounter_CAPTURE_MODE_CONF)
    #define InputCounter_DEFAULT_CAPTURE_MODE    ((uint8)((uint8)0u << InputCounter_CTRL_CAPMODE0_SHIFT))
#else    
    #define InputCounter_DEFAULT_CAPTURE_MODE    (0u )
#endif /* ( 0 != InputCounter_CAPTURE_MODE_CONF) */

#endif /* (InputCounter_UsingFixedFunction) */


/**************************************
 *  Registers
 *************************************/
#if (InputCounter_UsingFixedFunction)
    #define InputCounter_STATICCOUNT_LSB     (*(reg16 *) InputCounter_CounterHW__CAP0 )
    #define InputCounter_STATICCOUNT_LSB_PTR ( (reg16 *) InputCounter_CounterHW__CAP0 )
    #define InputCounter_PERIOD_LSB          (*(reg16 *) InputCounter_CounterHW__PER0 )
    #define InputCounter_PERIOD_LSB_PTR      ( (reg16 *) InputCounter_CounterHW__PER0 )
    /* MODE must be set to 1 to set the compare value */
    #define InputCounter_COMPARE_LSB         (*(reg16 *) InputCounter_CounterHW__CNT_CMP0 )
    #define InputCounter_COMPARE_LSB_PTR     ( (reg16 *) InputCounter_CounterHW__CNT_CMP0 )
    /* MODE must be set to 0 to get the count */
    #define InputCounter_COUNTER_LSB         (*(reg16 *) InputCounter_CounterHW__CNT_CMP0 )
    #define InputCounter_COUNTER_LSB_PTR     ( (reg16 *) InputCounter_CounterHW__CNT_CMP0 )
    #define InputCounter_RT1                 (*(reg8 *) InputCounter_CounterHW__RT1)
    #define InputCounter_RT1_PTR             ( (reg8 *) InputCounter_CounterHW__RT1)
#else
    
    #if (InputCounter_Resolution <= 8u) /* 8-bit Counter */
    
        #define InputCounter_STATICCOUNT_LSB     (*(reg8 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
        #define InputCounter_STATICCOUNT_LSB_PTR ( (reg8 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
        #define InputCounter_PERIOD_LSB          (*(reg8 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
        #define InputCounter_PERIOD_LSB_PTR      ( (reg8 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
        #define InputCounter_COMPARE_LSB         (*(reg8 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
        #define InputCounter_COMPARE_LSB_PTR     ( (reg8 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
        #define InputCounter_COUNTER_LSB         (*(reg8 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )  
        #define InputCounter_COUNTER_LSB_PTR     ( (reg8 *)\
            InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )
    
    #elif(InputCounter_Resolution <= 16u) /* 16-bit Counter */
        #if(CY_PSOC3) /* 8-bit address space */ 
            #define InputCounter_STATICCOUNT_LSB     (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
            #define InputCounter_STATICCOUNT_LSB_PTR ( (reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
            #define InputCounter_PERIOD_LSB          (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
            #define InputCounter_PERIOD_LSB_PTR      ( (reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
            #define InputCounter_COMPARE_LSB         (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
            #define InputCounter_COMPARE_LSB_PTR     ( (reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
            #define InputCounter_COUNTER_LSB         (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )  
            #define InputCounter_COUNTER_LSB_PTR     ( (reg16 *)\
                InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define InputCounter_STATICCOUNT_LSB     (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_F0_REG )
            #define InputCounter_STATICCOUNT_LSB_PTR ( (reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_F0_REG )
            #define InputCounter_PERIOD_LSB          (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_D0_REG )
            #define InputCounter_PERIOD_LSB_PTR      ( (reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_D0_REG )
            #define InputCounter_COMPARE_LSB         (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_D1_REG )
            #define InputCounter_COMPARE_LSB_PTR     ( (reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_D1_REG )
            #define InputCounter_COUNTER_LSB         (*(reg16 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_A0_REG )  
            #define InputCounter_COUNTER_LSB_PTR     ( (reg16 *)\
                InputCounter_CounterUDB_sC24_counterdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */   
    #elif(InputCounter_Resolution <= 24u) /* 24-bit Counter */
        
        #define InputCounter_STATICCOUNT_LSB     (*(reg32 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
        #define InputCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
        #define InputCounter_PERIOD_LSB          (*(reg32 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
        #define InputCounter_PERIOD_LSB_PTR      ( (reg32 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
        #define InputCounter_COMPARE_LSB         (*(reg32 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
        #define InputCounter_COMPARE_LSB_PTR     ( (reg32 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
        #define InputCounter_COUNTER_LSB         (*(reg32 *) \
            InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )  
        #define InputCounter_COUNTER_LSB_PTR     ( (reg32 *)\
            InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )
    
    #else /* 32-bit Counter */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define InputCounter_STATICCOUNT_LSB     (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
            #define InputCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__F0_REG )
            #define InputCounter_PERIOD_LSB          (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
            #define InputCounter_PERIOD_LSB_PTR      ( (reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D0_REG )
            #define InputCounter_COMPARE_LSB         (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
            #define InputCounter_COMPARE_LSB_PTR     ( (reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__D1_REG )
            #define InputCounter_COUNTER_LSB         (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )  
            #define InputCounter_COUNTER_LSB_PTR     ( (reg32 *)\
                InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define InputCounter_STATICCOUNT_LSB     (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_F0_REG )
            #define InputCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_F0_REG )
            #define InputCounter_PERIOD_LSB          (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_D0_REG )
            #define InputCounter_PERIOD_LSB_PTR      ( (reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_D0_REG )
            #define InputCounter_COMPARE_LSB         (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_D1_REG )
            #define InputCounter_COMPARE_LSB_PTR     ( (reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_D1_REG )
            #define InputCounter_COUNTER_LSB         (*(reg32 *) \
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_A0_REG )  
            #define InputCounter_COUNTER_LSB_PTR     ( (reg32 *)\
                InputCounter_CounterUDB_sC24_counterdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */   
    #endif

	#define InputCounter_COUNTER_LSB_PTR_8BIT     ( (reg8 *)\
                InputCounter_CounterUDB_sC24_counterdp_u0__A0_REG )
				
    #define InputCounter_AUX_CONTROLDP0 \
        (*(reg8 *) InputCounter_CounterUDB_sC24_counterdp_u0__DP_AUX_CTL_REG)
    
    #define InputCounter_AUX_CONTROLDP0_PTR \
        ( (reg8 *) InputCounter_CounterUDB_sC24_counterdp_u0__DP_AUX_CTL_REG)
    
    #if (InputCounter_Resolution == 16 || InputCounter_Resolution == 24 || InputCounter_Resolution == 32)
       #define InputCounter_AUX_CONTROLDP1 \
           (*(reg8 *) InputCounter_CounterUDB_sC24_counterdp_u1__DP_AUX_CTL_REG)
       #define InputCounter_AUX_CONTROLDP1_PTR \
           ( (reg8 *) InputCounter_CounterUDB_sC24_counterdp_u1__DP_AUX_CTL_REG)
    #endif /* (InputCounter_Resolution == 16 || InputCounter_Resolution == 24 || InputCounter_Resolution == 32) */
    
    #if (InputCounter_Resolution == 24 || InputCounter_Resolution == 32)
       #define InputCounter_AUX_CONTROLDP2 \
           (*(reg8 *) InputCounter_CounterUDB_sC24_counterdp_u2__DP_AUX_CTL_REG)
       #define InputCounter_AUX_CONTROLDP2_PTR \
           ( (reg8 *) InputCounter_CounterUDB_sC24_counterdp_u2__DP_AUX_CTL_REG)
    #endif /* (InputCounter_Resolution == 24 || InputCounter_Resolution == 32) */
    
    #if (InputCounter_Resolution == 32)
       #define InputCounter_AUX_CONTROLDP3 \
           (*(reg8 *) InputCounter_CounterUDB_sC24_counterdp_u3__DP_AUX_CTL_REG)
       #define InputCounter_AUX_CONTROLDP3_PTR \
           ( (reg8 *) InputCounter_CounterUDB_sC24_counterdp_u3__DP_AUX_CTL_REG)
    #endif /* (InputCounter_Resolution == 32) */

#endif  /* (InputCounter_UsingFixedFunction) */

#if (InputCounter_UsingFixedFunction)
    #define InputCounter_STATUS         (*(reg8 *) InputCounter_CounterHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define InputCounter_STATUS_MASK             (*(reg8 *) InputCounter_CounterHW__SR0 )
    #define InputCounter_STATUS_MASK_PTR         ( (reg8 *) InputCounter_CounterHW__SR0 )
    #define InputCounter_CONTROL                 (*(reg8 *) InputCounter_CounterHW__CFG0)
    #define InputCounter_CONTROL_PTR             ( (reg8 *) InputCounter_CounterHW__CFG0)
    #define InputCounter_CONTROL2                (*(reg8 *) InputCounter_CounterHW__CFG1)
    #define InputCounter_CONTROL2_PTR            ( (reg8 *) InputCounter_CounterHW__CFG1)
    #if (CY_PSOC3 || CY_PSOC5LP)
        #define InputCounter_CONTROL3       (*(reg8 *) InputCounter_CounterHW__CFG2)
        #define InputCounter_CONTROL3_PTR   ( (reg8 *) InputCounter_CounterHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define InputCounter_GLOBAL_ENABLE           (*(reg8 *) InputCounter_CounterHW__PM_ACT_CFG)
    #define InputCounter_GLOBAL_ENABLE_PTR       ( (reg8 *) InputCounter_CounterHW__PM_ACT_CFG)
    #define InputCounter_GLOBAL_STBY_ENABLE      (*(reg8 *) InputCounter_CounterHW__PM_STBY_CFG)
    #define InputCounter_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) InputCounter_CounterHW__PM_STBY_CFG)
    

    /********************************
    *    Constants
    ********************************/

    /* Fixed Function Block Chosen */
    #define InputCounter_BLOCK_EN_MASK          InputCounter_CounterHW__PM_ACT_MSK
    #define InputCounter_BLOCK_STBY_EN_MASK     InputCounter_CounterHW__PM_STBY_MSK 
    
    /* Control Register Bit Locations */    
    /* As defined in Register Map, part of TMRX_CFG0 register */
    #define InputCounter_CTRL_ENABLE_SHIFT      0x00u
    #define InputCounter_ONESHOT_SHIFT          0x02u
    /* Control Register Bit Masks */
    #define InputCounter_CTRL_ENABLE            ((uint8)((uint8)0x01u << InputCounter_CTRL_ENABLE_SHIFT))         
    #define InputCounter_ONESHOT                ((uint8)((uint8)0x01u << InputCounter_ONESHOT_SHIFT))

    /* Control2 Register Bit Masks */
    /* Set the mask for run mode */
    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        #define InputCounter_CTRL_MODE_SHIFT        0x01u    
        #define InputCounter_CTRL_MODE_MASK         ((uint8)((uint8)0x07u << InputCounter_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Use CFG2 Mode bits to set run mode */
        #define InputCounter_CTRL_MODE_SHIFT        0x00u    
        #define InputCounter_CTRL_MODE_MASK         ((uint8)((uint8)0x03u << InputCounter_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    /* Set the mask for interrupt (raw/status register) */
    #define InputCounter_CTRL2_IRQ_SEL_SHIFT     0x00u
    #define InputCounter_CTRL2_IRQ_SEL          ((uint8)((uint8)0x01u << InputCounter_CTRL2_IRQ_SEL_SHIFT))     
    
    /* Status Register Bit Locations */
    #define InputCounter_STATUS_ZERO_SHIFT      0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 

    /* Status Register Interrupt Enable Bit Locations */
    #define InputCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      (InputCounter_STATUS_ZERO_SHIFT - 0x04u)

    /* Status Register Bit Masks */                           
    #define InputCounter_STATUS_ZERO            ((uint8)((uint8)0x01u << InputCounter_STATUS_ZERO_SHIFT))

    /* Status Register Interrupt Bit Masks*/
    #define InputCounter_STATUS_ZERO_INT_EN_MASK       ((uint8)((uint8)InputCounter_STATUS_ZERO >> 0x04u))
    
    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define InputCounter_RT1_SHIFT            0x04u
    #define InputCounter_RT1_MASK             ((uint8)((uint8)0x03u << InputCounter_RT1_SHIFT))  /* Sync TC and CMP bit masks */
    #define InputCounter_SYNC                 ((uint8)((uint8)0x03u << InputCounter_RT1_SHIFT))
    #define InputCounter_SYNCDSI_SHIFT        0x00u
    #define InputCounter_SYNCDSI_MASK         ((uint8)((uint8)0x0Fu << InputCounter_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    #define InputCounter_SYNCDSI_EN           ((uint8)((uint8)0x0Fu << InputCounter_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    
#else /* !InputCounter_UsingFixedFunction */
    #define InputCounter_STATUS               (* (reg8 *) InputCounter_CounterUDB_sSTSReg_stsreg__STATUS_REG )
    #define InputCounter_STATUS_PTR           (  (reg8 *) InputCounter_CounterUDB_sSTSReg_stsreg__STATUS_REG )
    #define InputCounter_STATUS_MASK          (* (reg8 *) InputCounter_CounterUDB_sSTSReg_stsreg__MASK_REG )
    #define InputCounter_STATUS_MASK_PTR      (  (reg8 *) InputCounter_CounterUDB_sSTSReg_stsreg__MASK_REG )
    #define InputCounter_STATUS_AUX_CTRL      (*(reg8 *) InputCounter_CounterUDB_sSTSReg_stsreg__STATUS_AUX_CTL_REG)
    #define InputCounter_STATUS_AUX_CTRL_PTR  ( (reg8 *) InputCounter_CounterUDB_sSTSReg_stsreg__STATUS_AUX_CTL_REG)
    #define InputCounter_CONTROL              (* (reg8 *) InputCounter_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )
    #define InputCounter_CONTROL_PTR          (  (reg8 *) InputCounter_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )


    /********************************
    *    Constants
    ********************************/
    /* Control Register Bit Locations */
    #define InputCounter_CTRL_CAPMODE0_SHIFT    0x03u       /* As defined by Verilog Implementation */
    #define InputCounter_CTRL_RESET_SHIFT       0x06u       /* As defined by Verilog Implementation */
    #define InputCounter_CTRL_ENABLE_SHIFT      0x07u       /* As defined by Verilog Implementation */
    /* Control Register Bit Masks */
    #define InputCounter_CTRL_CMPMODE_MASK      0x07u 
    #define InputCounter_CTRL_CAPMODE_MASK      0x03u  
    #define InputCounter_CTRL_RESET             ((uint8)((uint8)0x01u << InputCounter_CTRL_RESET_SHIFT))  
    #define InputCounter_CTRL_ENABLE            ((uint8)((uint8)0x01u << InputCounter_CTRL_ENABLE_SHIFT)) 

    /* Status Register Bit Locations */
    #define InputCounter_STATUS_CMP_SHIFT       0x00u       /* As defined by Verilog Implementation */
    #define InputCounter_STATUS_ZERO_SHIFT      0x01u       /* As defined by Verilog Implementation */
    #define InputCounter_STATUS_OVERFLOW_SHIFT  0x02u       /* As defined by Verilog Implementation */
    #define InputCounter_STATUS_UNDERFLOW_SHIFT 0x03u       /* As defined by Verilog Implementation */
    #define InputCounter_STATUS_CAPTURE_SHIFT   0x04u       /* As defined by Verilog Implementation */
    #define InputCounter_STATUS_FIFOFULL_SHIFT  0x05u       /* As defined by Verilog Implementation */
    #define InputCounter_STATUS_FIFONEMP_SHIFT  0x06u       /* As defined by Verilog Implementation */
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define InputCounter_STATUS_CMP_INT_EN_MASK_SHIFT       InputCounter_STATUS_CMP_SHIFT       
    #define InputCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      InputCounter_STATUS_ZERO_SHIFT      
    #define InputCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT  InputCounter_STATUS_OVERFLOW_SHIFT  
    #define InputCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT InputCounter_STATUS_UNDERFLOW_SHIFT 
    #define InputCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT   InputCounter_STATUS_CAPTURE_SHIFT   
    #define InputCounter_STATUS_FIFOFULL_INT_EN_MASK_SHIFT  InputCounter_STATUS_FIFOFULL_SHIFT  
    #define InputCounter_STATUS_FIFONEMP_INT_EN_MASK_SHIFT  InputCounter_STATUS_FIFONEMP_SHIFT  
    /* Status Register Bit Masks */                
    #define InputCounter_STATUS_CMP             ((uint8)((uint8)0x01u << InputCounter_STATUS_CMP_SHIFT))  
    #define InputCounter_STATUS_ZERO            ((uint8)((uint8)0x01u << InputCounter_STATUS_ZERO_SHIFT)) 
    #define InputCounter_STATUS_OVERFLOW        ((uint8)((uint8)0x01u << InputCounter_STATUS_OVERFLOW_SHIFT)) 
    #define InputCounter_STATUS_UNDERFLOW       ((uint8)((uint8)0x01u << InputCounter_STATUS_UNDERFLOW_SHIFT)) 
    #define InputCounter_STATUS_CAPTURE         ((uint8)((uint8)0x01u << InputCounter_STATUS_CAPTURE_SHIFT)) 
    #define InputCounter_STATUS_FIFOFULL        ((uint8)((uint8)0x01u << InputCounter_STATUS_FIFOFULL_SHIFT))
    #define InputCounter_STATUS_FIFONEMP        ((uint8)((uint8)0x01u << InputCounter_STATUS_FIFONEMP_SHIFT))
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define InputCounter_STATUS_CMP_INT_EN_MASK            InputCounter_STATUS_CMP                    
    #define InputCounter_STATUS_ZERO_INT_EN_MASK           InputCounter_STATUS_ZERO            
    #define InputCounter_STATUS_OVERFLOW_INT_EN_MASK       InputCounter_STATUS_OVERFLOW        
    #define InputCounter_STATUS_UNDERFLOW_INT_EN_MASK      InputCounter_STATUS_UNDERFLOW       
    #define InputCounter_STATUS_CAPTURE_INT_EN_MASK        InputCounter_STATUS_CAPTURE         
    #define InputCounter_STATUS_FIFOFULL_INT_EN_MASK       InputCounter_STATUS_FIFOFULL        
    #define InputCounter_STATUS_FIFONEMP_INT_EN_MASK       InputCounter_STATUS_FIFONEMP         
    

    /* StatusI Interrupt Enable bit Location in the Auxilliary Control Register */
    #define InputCounter_STATUS_ACTL_INT_EN     0x10u /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define InputCounter_AUX_CTRL_FIFO0_CLR         0x01u   /* As defined by Register map */
    #define InputCounter_AUX_CTRL_FIFO1_CLR         0x02u   /* As defined by Register map */
    #define InputCounter_AUX_CTRL_FIFO0_LVL         0x04u   /* As defined by Register map */
    #define InputCounter_AUX_CTRL_FIFO1_LVL         0x08u   /* As defined by Register map */
    #define InputCounter_STATUS_ACTL_INT_EN_MASK    0x10u   /* As defined for the ACTL Register */
    
#endif /* InputCounter_UsingFixedFunction */

#endif  /* CY_COUNTER_InputCounter_H */


/* [] END OF FILE */

